"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const vscode_languageserver_1 = require("vscode-languageserver");
function isWindows() {
    return /^win/.test(process.platform);
}
exports.isWindows = isWindows;
function uriToPath(uri) {
    const p = path.resolve(uri.replace(/file:\/\/\//, ''));
    return isWindows() ? p.replace(/\//g, '\\') : p;
}
exports.uriToPath = uriToPath;
function pathToUri(p) {
    return 'file://' + (isWindows() ? '/' + p.replace(/\//g, '/') : p);
}
exports.pathToUri = pathToUri;
function tsServerFileSpanToLspLocation(fileSpan) {
    return {
        uri: pathToUri(fileSpan.file),
        range: {
            start: {
                line: fileSpan.start.line - 1,
                character: fileSpan.start.offset - 1
            },
            end: {
                line: fileSpan.end.line - 1,
                character: fileSpan.end.offset - 1
            }
        }
    };
}
exports.tsServerFileSpanToLspLocation = tsServerFileSpanToLspLocation;
exports.completionKindsMapping = {
    class: vscode_languageserver_1.CompletionItemKind.Class,
    constructor: vscode_languageserver_1.CompletionItemKind.Constructor,
    enum: vscode_languageserver_1.CompletionItemKind.Enum,
    field: vscode_languageserver_1.CompletionItemKind.Field,
    file: vscode_languageserver_1.CompletionItemKind.File,
    function: vscode_languageserver_1.CompletionItemKind.Function,
    interface: vscode_languageserver_1.CompletionItemKind.Interface,
    keyword: vscode_languageserver_1.CompletionItemKind.Keyword,
    method: vscode_languageserver_1.CompletionItemKind.Method,
    module: vscode_languageserver_1.CompletionItemKind.Module,
    property: vscode_languageserver_1.CompletionItemKind.Property,
    reference: vscode_languageserver_1.CompletionItemKind.Reference,
    snippet: vscode_languageserver_1.CompletionItemKind.Snippet,
    text: vscode_languageserver_1.CompletionItemKind.Text,
    unit: vscode_languageserver_1.CompletionItemKind.Unit,
    value: vscode_languageserver_1.CompletionItemKind.Value,
    variable: vscode_languageserver_1.CompletionItemKind.Variable
};
class Deferred {
    constructor() {
        this.promise = new Promise((resolve, reject) => {
            this.resolve = resolve;
            this.reject = reject;
        });
    }
}
exports.Deferred = Deferred;
